NAME
Paws::Shield::Contributor
USAGE
This class represents one of two things:
Arguments in a call to a service
Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. Each attribute should be used as a named argument in the calls that expect this type of object.
As an example, if Att1 is expected to be a Paws::Shield::Contributor object:
$service_obj->Method(Att1 => { Name => $value, ..., Value => $value });
Results returned from an API call
Use accessors for each attribute. If Att1 is expected to be an Paws::Shield::Contributor object:
$result = $service_obj->Method(...);
$result->Att1->Name
DESCRIPTION
A contributor to the attack and their contribution.
ATTRIBUTES
Name => Str
The name of the contributor. This is dependent on the
C<AttackPropertyIdentifier>. For example, if the
C<AttackPropertyIdentifier> is C<SOURCE_COUNTRY>, the C<Name> could be
C<United States>.
Value => Int
The contribution of this contributor expressed in Protection units. For
example C<10,000>.
SEE ALSO
This class forms part of Paws, describing an object used in Paws::Shield
BUGS and CONTRIBUTIONS
The source code is located here: https://github.com/pplu/aws-sdk-perl
Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues